Py4JMember (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j.model

## Class Py4JMember

- java.lang.Object
- - py4j.model.Py4JMember

- All Implemented Interfaces:
    java.lang.Comparable<Py4JMember>
  Direct Known Subclasses:
    Py4JClass, Py4JField, Py4JMethod

      public abstract class Py4JMember
      extends java.lang.Object
      implements java.lang.Comparable<Py4JMember>

  Model of a Java member (class, method, or field) used to create a help page.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `Py4JMember(java.lang.String name, java.lang.String javadoc)`

  - ### Method Summary

    All Methods Instance Methods Abstract Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `int` | `compareTo(Py4JMember o)`
    `boolean` | `equals(java.lang.Object obj)`
    `java.lang.String` | `getJavadoc()`
    `java.lang.String` | `getName()`
    `abstract java.lang.String` | `getSignature(boolean shortName)`
    `int` | `hashCode()`

    - ### Methods inherited from class java.lang.Object

      `clone, finalize, getClass, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### Py4JMember

          public Py4JMember(java.lang.String name,
                            java.lang.String javadoc)

  - ### Method Detail

    - #### compareTo

          public int compareTo(Py4JMember o)

      Specified by:
        `compareTo` in interface `java.lang.Comparable<Py4JMember>`

    - #### equals

          public boolean equals(java.lang.Object obj)

      Overrides:
        `equals` in class `java.lang.Object`

    - #### hashCode

          public int hashCode()

      Overrides:
        `hashCode` in class `java.lang.Object`

    - #### getJavadoc

          public java.lang.String getJavadoc()

    - #### getName

          public java.lang.String getName()

    - #### getSignature

          public abstract java.lang.String getSignature(boolean shortName)